@@ -20,7 +20,7 @@
  *
  */
 
-/* $Id: calendar-conduit.c,v 1.34 2002/03/10 20:53:32 srittau Exp $ */
+/* $Id: calendar-conduit.c,v 1.36 2002/08/16 17:57:53 srittau Exp $ */
 
 #define G_LOG_DOMAIN "gcalconduit" 
 
@@ -56,6 +56,9 @@
 
 #include <unistd.h>
 
+gboolean roll_at_midnight = FALSE;
+GList *all_calendars = NULL;
+
 int debug_alarms = 0;  /* needed to satisfy some other part of gncal */
 /* Default values for alarms */ /* needed to satisfy some other part of gncal */
 CalendarAlarm alarm_defaults[4] = {
