@@ -12,13 +12,21 @@
  *
  */
 
-#include <gnome.h>
-#include <stdio.h>
 #include <config.h>
+
+#include <stdio.h>
 #include <unistd.h>
+#include <errno.h>
+#include <sys/types.h>
 #include <sys/stat.h>
-#include "calendar.h"
+
+#include <glib.h>
+#include <gnome.h>
+
 #include "alarm.h"
+#include "calendar.h"
+#include "gnome-cal.h"
+#include "main.h"
 #include "timeutil.h"
 #include "../libversit/vcc.h"
 
@@ -33,7 +41,7 @@ static void calendar_init_alarms (Calendar *cal);
 static void calendar_set_day (void);
 
 Calendar *
-calendar_new (char *title)
+calendar_new (char *title,CalendarNewOptions options)
 {
 	Calendar *cal;
 
@@ -46,7 +54,9 @@ calendar_new (char *title)
 
 	cal->event_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	
-	calendar_init_alarms (cal);
+	if (options & CALENDAR_INIT_ALARMS) {
+		calendar_init_alarms (cal);
+	}
 	
 	return cal;
 }
@@ -374,7 +384,7 @@ vcalendar_create_from_calendar (Calendar *cal)
 #elif defined(HAVE_TZNAME)
 	addPropValue (vcal, VCTimeZoneProp, tzname[0]);
 #endif
-	addPropValue (vcal, VCVersionProp, VERSION);
+	addPropValue (vcal, VCVersionProp, "1.0");
 	cal->temp = vcal;
 
 	/* Events */
@@ -399,47 +409,88 @@ vcalendar_create_from_calendar (Calendar *cal)
 }
 
 void
-calendar_save (Calendar *cal, char *fname)
+calendar_save (Calendar *cal, const gchar *fname)
 {
-	VObject *vcal;
-	FILE *fp;
-	GtkWidget *dlg;
-	struct  stat s;
-	int status;
-	
+	gchar *backup_name;
+	gchar *error_msg = NULL;
+	int my_errno;
+
+	g_return_if_fail (cal != NULL);
+	g_return_if_fail (fname != NULL || cal->filename != NULL);
+
+	/* file name setup */
 	if (fname == NULL)
 		fname = cal->filename;
+	backup_name = g_strconcat (fname, "~", NULL);
 
-	vcal = vcalendar_create_from_calendar (cal);
-	if (g_file_exists (fname)){
-		char *backup_name = g_strconcat (fname, "~", NULL);
-
-		if (g_file_exists (backup_name)){
-			unlink (backup_name);
+	/* create backup file */
+	if (g_file_exists (fname)) {
+		if (rename (fname, backup_name) == -1) {
+			error_msg = _("Error while creating backup file: %s");
+			my_errno = errno;
 		}
-		rename (fname, backup_name);
-		g_free (backup_name);
 	}
 
-	fp = fopen(fname,"w");
-	if (fp) {
-		writeVObject(fp, vcal);
-		fclose(fp);
-		if (strcmp(cal->filename, fname)) {
-			if (cal->filename)
-				g_free (cal->filename);
+	if (!error_msg) {
+		FILE *fp;
+		VObject *vcal;
+
+		vcal = vcalendar_create_from_calendar (cal);
+
+		fp = fopen (fname, "wb");
+		if (fp) {
+			int e;
+
+			writeVObject(fp, vcal);
+			e = ferror (fp);
+			fclose(fp);
+
+			if (e) {
+				/* try to restore the backup file */
+				rename (backup_name, fname);
+
+				error_msg = _("Error writing the calendar file: %s");
+				my_errno = errno;
+			}
+		} else {
+			error_msg = _("Error writing the calendar file: %s");
+			my_errno = errno;
+		}
+
+		cleanVObject (vcal); 
+		cleanStrTbl ();
+	}
+
+	/* update calendar */
+	if (!error_msg) {
+		struct stat s;
+
+		if (fname != cal->filename) {
+			g_free (cal->filename);
 			cal->filename = g_strdup (fname);
 		}
-		status = stat (fname, &s);
+		stat (fname, &s);
 		cal->file_time = s.st_mtime;
-	} else {
-		dlg = gnome_message_box_new(_("Failed to save calendar!"), 
-					    GNOME_MESSAGE_BOX_ERROR, "Ok", NULL);
-		gtk_widget_show(dlg);
 	}
-	
-	cleanVObject (vcal); 
-	cleanStrTbl ();
+
+	/* error handling */
+	if (error_msg) {
+		GtkWidget *dialog;
+		gchar *s;
+
+		s = g_strdup_printf (error_msg, strerror (my_errno));
+
+		dialog = gnome_message_box_new (s,
+						GNOME_MESSAGE_BOX_ERROR,
+						GNOME_STOCK_BUTTON_OK,
+						NULL);
+		gtk_widget_show (dialog);
+
+		g_free (s);
+	}
+
+	/* clean up */	
+	g_free (backup_name);
 }
 
 char *
@@ -535,6 +586,17 @@ calendar_day_change (time_t time, CalendarAlarm *which, void *closure)
 
 		ical_object_try_alarms (obj);
 	}
+
+	if (roll_at_midnight) {
+		GList *l;
+
+		for (l = all_calendars; l; l = l->next) {
+			GnomeCalendar *gcal = (GnomeCalendar *) l->data;
+
+			/* FIXME: do this only if date of calendar is yesterday */
+			gnome_calendar_goto_today (gcal);
+		}
+	}
 }
 
 static void
@@ -633,7 +695,7 @@ calendar_string_from_object (iCalObject *object)
 
 	g_return_val_if_fail (object != NULL, NULL);
 	
-	cal = calendar_new ("Temporal");
+	cal = calendar_new ("Temporal",CALENDAR_INIT_NIL);
 	calendar_add_object (cal, object);
 	str = calendar_get_as_vcal_string (cal);
 	calendar_remove_object (cal, object);
