@@ -57,6 +57,7 @@ ical_object_new (void)
 
 	ico->pilot_id = 0;
 	ico->pilot_status = ICAL_PILOT_SYNC_MOD;
+	ico->allday = FALSE;
 
 	ico->priority = 5;
 	
@@ -674,7 +675,7 @@ ical_object_create_from_vobject (VObject *o, const char *object_name)
 		ical->class = g_strdup (str_val (vo));
 		free (the_str);
 	} else
-		ical->class = "PUBLIC";
+		ical->class = g_strdup ("PUBLIC");
 
 	/* categories */
 	if (has (o, VCCategoriesProp)){
@@ -783,7 +784,7 @@ ical_object_create_from_vobject (VObject *o, const char *object_name)
 	}
 
 	/* rrule */
-	if (has (o, VCRRuleProp)){
+	if (has (o, VCRRuleProp)) {
 		if (!load_recurrence (ical, str_val (vo))) {
 			ical_object_destroy (ical);
 			return NULL;
@@ -797,14 +798,27 @@ ical_object_create_from_vobject (VObject *o, const char *object_name)
 	if (has (o, XPilotIdProp)){
 		ical->pilot_id = atoi (str_val (vo));
 		free (the_str);
-	} else
+	} else {
 		ical->pilot_id = 0;
+	}
+
+	if (has (o, XPilotNoTimeProp)){
+		int notime_state = atoi (str_val (vo));
+		if (notime_state) {
+			ical->allday = TRUE;
+		} else {
+			ical->allday = FALSE;
+		}
+	} else {
+		ical->pilot_id = 0;
+	}
 
 	if (has (o, XPilotStatusProp)){
 		ical->pilot_status = atoi (str_val (vo));
 		free (the_str);
-	} else
+	} else {
 		ical->pilot_status = ICAL_PILOT_SYNC_MOD;
+	}
 	
 	return ical;
 }
@@ -942,10 +956,17 @@ ical_object_to_vobject (iCalObject *ical)
 	addPropValue (o, VCDTstartProp, isodate_from_time_t (ical->dtstart));
 
 	/* dtend */
-	if (ical->type == ICAL_EVENT){
-		addPropValue (o, VCDTendProp, isodate_from_time_t (ical->dtend));
-	} else if (ical->type == ICAL_TODO){
-		addPropValue (o, VCDueProp, isodate_from_time_t (ical->dtend));
+	/* Save this only if it's non-null. Note that this means you can't
+	 * schedule appointments at the start of the epoch. (Jan 1 1970,
+	 * 00:00) (It's probably hard for you guys living in the past,
+	 * but hey, that's life...)
+	 */
+	if (ical->dtend) {
+		if (ical->type == ICAL_EVENT) {
+			addPropValue (o, VCDTendProp, isodate_from_time_t (ical->dtend));
+		} else if (ical->type == ICAL_TODO) {
+			addPropValue (o, VCDueProp, isodate_from_time_t (ical->dtend));
+		}
 	}
 
 	/* dcreated */
@@ -1078,8 +1099,12 @@ ical_object_to_vobject (iCalObject *ical)
 		
 		sprintf (buffer, "%d", ical->pilot_id);
 		addPropValue (o, XPilotIdProp, buffer);
+
 		sprintf (buffer, "%d", ical->pilot_status);
 		addPropValue (o, XPilotStatusProp, buffer);
+
+		sprintf (buffer, "%d", ical->allday ? 1 : 0);
+		addPropValue (o, XPilotNoTimeProp, buffer);
 	}
 	
 	return o;
@@ -1218,13 +1243,18 @@ ical_object_generate_events (iCalObject *ico, time_t start, time_t end, calendar
 	switch (ico->recur->type) {
 	case RECUR_DAILY:
 		do {
+			int ndays;
 			if (time_in_range (current, start, end) && recur_in_range (current, ico->recur))
 				if (!generate (ico, current, cb, closure))
 					return;
 
 			/* Advance */
 
-			current = time_add_day (current, ico->recur->interval);
+			if (ico->recur->interval > 0)
+				ndays = ico->recur->interval;
+			else
+				ndays = 1;
+			current = time_add_day (current, ndays);
 
 			if (current == -1) {
 				g_warning ("RECUR_DAILY: time_add_day() returned invalid time");
@@ -1237,6 +1267,7 @@ ical_object_generate_events (iCalObject *ico, time_t start, time_t end, calendar
 	case RECUR_WEEKLY:
 		do {
 			struct tm tm;
+			int ndays;
 
 			tm = *localtime (&current);
 
@@ -1251,9 +1282,14 @@ ical_object_generate_events (iCalObject *ico, time_t start, time_t end, calendar
 			/* Advance by day for scanning the week or by interval at week end */
 
 			if (tm.tm_wday == 6)
-				current = time_add_day (current, (ico->recur->interval - 1) * 7 + 1);
+				ndays = (ico->recur->interval - 1) * 7 + 1;
 			else
-				current = time_add_day (current, 1);
+				ndays = 1;
+
+			if (ndays <= 0)
+				ndays = 1;
+
+			current = time_add_day (current, ndays);
 
 			if (current == -1) {
 				g_warning ("RECUR_WEEKLY: time_add_day() returned invalid time\n");
