@@ -21,7 +21,6 @@ static void event_editor_destroy    (GtkObject        *object);
 GtkWidget* make_spin_button (int val, int low, int high);
 void ee_create_ae (GtkTable *table, char *str, CalendarAlarm *alarm, enum AlarmType type, 
 		   int y, gboolean control_sens, GtkSignalFunc dirty_func);
-void ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type);
 
 static gint ee_validity_check (EventEditor *ee);
 
@@ -302,6 +301,7 @@ timesel_new (void)
 		GtkWidget *item;
 
 		item = gtk_menu_item_new_with_label (_(items [i]));
+		gtk_object_set_data (GTK_OBJECT (item), "index", GINT_TO_POINTER (i));
 		gtk_menu_append (GTK_MENU (menu), item);
 		gtk_widget_show (item);
 	}
@@ -384,7 +384,7 @@ ee_create_ae (GtkTable *table, char *str, CalendarAlarm *alarm, enum AlarmType t
 
 	case ALARM_PROGRAM:
 		alarm->w_label = gtk_label_new (_("Run program:"));
-		gtk_misc_set_alignment (GTK_MISC (alarm->w_label), 1.0, 0.5);	
+		gtk_misc_set_alignment (GTK_MISC (alarm->w_label), 1.0, 0.5);
 		gtk_table_attach (table, alarm->w_label, 3, 4, y, y+1, FS, FS, 0, 0);
 		alarm->w_entry = gnome_file_entry_new ("alarm-program", _("Select program to run at alarm time"));
 		entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (alarm->w_entry));
@@ -468,12 +468,10 @@ ee_classification_widgets (EventEditor *ee)
  * on the CalendarAlarm generic values
  */
 void
-ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type)
+ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type, gboolean exit_if_disabled)
 {
 	GtkWidget *item;
 	GtkMenu   *menu;
-	GList     *child;
-	int idx;
 	
 	if (alarm->data){
 		g_free (alarm->data);
@@ -482,7 +480,7 @@ ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type)
 	
 	alarm->enabled = GTK_TOGGLE_BUTTON (alarm->w_enabled)->active;
 
-	if (!alarm->enabled)
+	if (exit_if_disabled && !alarm->enabled)
 		return;
 	
 	if (type == ALARM_PROGRAM)
@@ -495,10 +493,7 @@ ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type)
 	
 	item = gtk_menu_get_active (menu);
 	
-	for (idx = 0, child = GTK_MENU_SHELL (menu)->children; child->data != item; child = child->next)
-		idx++;
-	
-	alarm->units = idx;
+	alarm->units = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (item), "index"));
 	alarm->count = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (alarm->w_count));
 }
 
@@ -520,10 +515,10 @@ ee_store_general_values_to_ical (EventEditor *ee)
 
 	ical->summary = gtk_editable_get_chars (GTK_EDITABLE (ee->general_summary), 0, -1);
 
-	ee_store_alarm (&ical->dalarm, ALARM_DISPLAY);
-	ee_store_alarm (&ical->aalarm, ALARM_AUDIO);
-	ee_store_alarm (&ical->palarm, ALARM_PROGRAM);
-	ee_store_alarm (&ical->malarm, ALARM_MAIL);
+	ee_store_alarm (&ical->dalarm, ALARM_DISPLAY, TRUE);
+	ee_store_alarm (&ical->aalarm, ALARM_AUDIO,   TRUE);
+	ee_store_alarm (&ical->palarm, ALARM_PROGRAM, TRUE);
+	ee_store_alarm (&ical->malarm, ALARM_MAIL,    TRUE);
 
 	for (idx = 2; list; list = list->next) {
 		if (GTK_TOGGLE_BUTTON (list->data)->active)
