@@ -10,15 +10,17 @@
 #include <signal.h>
 #include <sys/wait.h>
 #include <fcntl.h>
+
+#include "alarm.h"
 #include "calendar.h"
+#include "corba-cal.h"
 #include "gnome-cal.h"
 #include "gncal-day-panel.h"
 #include "gncal-week-view.h"
-#include "month-view.h"
-#include "year-view.h"
-#include "timeutil.h"
 #include "main.h"
-#include "corba-cal.h"
+#include "month-view.h"
+#include "timeutil.h"
+#include "year-view.h"
 
 GnomeApp *parent_class;
 
@@ -76,7 +78,13 @@ setup_widgets (GnomeCalendar *gcal)
 static GtkWidget *
 get_current_page (GnomeCalendar *gcal)
 {
-	return GTK_NOTEBOOK (gcal->notebook)->cur_page->child;
+	GtkNotebookPage *page;
+
+	page = GTK_NOTEBOOK (gcal->notebook)->cur_page;
+	if (page)
+		return page->child;
+	else
+		return NULL;
 }
 
 char *
@@ -111,6 +119,9 @@ gnome_calendar_goto (GnomeCalendar *gcal, time_t new_time)
 	g_return_if_fail (new_time != -1);
 
 	current = get_current_page (gcal);
+	if (!current)
+		return;
+	
 	new_time = time_day_begin (new_time);
 
 	if (current == gcal->day_view) {
@@ -360,7 +371,7 @@ execute (char *command, int close_standard)
 	sigaction (SIGQUIT, &save_quit, NULL);
 }
 
-void
+static void
 mail_notify (char *mail_address, char *text, time_t app_time)
 {
 	pid_t pid;
