@@ -12,7 +12,7 @@
 #include "gnome-month-item.h"
 
 
-#define DEFAULT_FONT "-*-helvetica-medium-r-normal--10-*-*-*-p-*-*-*"
+#define DEFAULT_FONT N_("-*-helvetica-medium-r-normal--10-*-*-*-p-*-*-*")
 
 
 /* Number of days in a month, for normal and leap years */
@@ -749,15 +749,15 @@ static void
 gnome_month_item_init (GnomeMonthItem *mitem)
 {
 	time_t t;
-	struct tm *tm;
+	struct tm tm;
 
 	/* Initialize to the current month by default */
 
 	t = time (NULL);
-	tm = localtime (&t);
+	tm = *localtime (&t);
 
-	mitem->year = tm->tm_year + 1900;
-	mitem->month = tm->tm_mon;
+	mitem->year = tm.tm_year + 1900;
+	mitem->month = tm.tm_mon;
 
 	mitem->x = 0.0;
 	mitem->y = 0.0;
@@ -772,13 +772,13 @@ gnome_month_item_init (GnomeMonthItem *mitem)
 
 	/* Load the default fonts */
 
-	mitem->head_font = gdk_font_load (DEFAULT_FONT);
+	mitem->head_font = gdk_fontset_load (_(DEFAULT_FONT));
 	if (!mitem->head_font) {
 		mitem->head_font = gdk_font_load ("fixed");
 		g_assert (mitem->head_font != NULL);
 	}
 
-	mitem->day_font = gdk_font_load (DEFAULT_FONT);
+	mitem->day_font = gdk_fontset_load (_(DEFAULT_FONT));
 	if (!mitem->day_font) {
 		mitem->day_font = gdk_font_load ("fixed");
 		g_assert (mitem->day_font != NULL);
@@ -971,7 +971,7 @@ gnome_month_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	case ARG_HEAD_FONT:
 		gdk_font_unref (mitem->head_font);
 
-		mitem->head_font = gdk_font_load (GTK_VALUE_STRING (*arg));
+		mitem->head_font = gdk_fontset_load (GTK_VALUE_STRING (*arg));
 		if (!mitem->head_font) {
 			mitem->head_font = gdk_font_load ("fixed");
 			g_assert (mitem->head_font != NULL);
@@ -1007,7 +1007,7 @@ gnome_month_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	case ARG_DAY_FONT:
 		gdk_font_unref (mitem->day_font);
 
-		mitem->day_font = gdk_font_load (GTK_VALUE_STRING (*arg));
+		mitem->day_font = gdk_fontset_load (GTK_VALUE_STRING (*arg));
 		if (!mitem->day_font) {
 			mitem->day_font = gdk_font_load ("fixed");
 			g_assert (mitem->day_font != NULL);
