@@ -5,6 +5,10 @@
  * Authors:
  *          Miguel de Icaza (miguel@kernel.org)
  *          Federico Mena (federico@nuclecu.unam.mx)
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>.
+ *
+ * $Id: main.c,v 1.108 2002/08/06 05:08:10 srittau Exp $
  */
 
 #include <config.h>
@@ -156,13 +160,8 @@ init_default_alarms (void)
 		}
 		
 		alarm_defaults[i].enabled = gnome_config_get_int ("enabled=0");
-		if (alarm_defaults[i].type != ALARM_MAIL) {
-			alarm_defaults[i].count   = gnome_config_get_int ("count=15");
-			alarm_defaults[i].units   = gnome_config_get_int ("units=0");
-		} else {
-			alarm_defaults[i].count   = gnome_config_get_int ("count=1");
-			alarm_defaults[i].count   = gnome_config_get_int ("count=2");
-		}
+		alarm_defaults[i].count   = gnome_config_get_int ("count=15");
+		alarm_defaults[i].units = gnome_config_get_int ("units=0");
 		
 		alarm_defaults[i].data = gnome_config_get_string_with_default ("data=",
 									       &def);
