@@ -4,6 +4,10 @@
  *
  * Authors: Miguel de Icaza <miguel@kernel.org>
  *          Federico Mena <federico@nuclecu.unam.mx>
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>.
+ *
+ * $Id: prop.c,v 1.35 2002/08/06 05:08:10 srittau Exp $
  */
 #include <config.h>
 #ifdef HAVE_LANGINGO_H
@@ -73,7 +77,7 @@ GtkWidget* make_spin_button (int val, int low, int high);
 void ee_create_ae (GtkTable *table, char *str, CalendarAlarm *alarm,
 		   enum AlarmType type, int y, gboolean sens,
 		   GtkSignalFunc dirty_func);
-void ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type);
+void ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type, gboolean exit_if_disabled);
 
 /* Callback used when the property box is closed -- just sets the prop_win variable to null. */
 static int
@@ -878,7 +882,7 @@ create_alarm_page (void)
 	gtk_table_set_row_spacings (GTK_TABLE (default_table), 4);
 	gtk_table_set_col_spacings (GTK_TABLE (default_table), 4);
 	gtk_container_add (GTK_CONTAINER (default_frame), default_table);
-		    
+
 	ee_create_ae (GTK_TABLE (default_table), _("Display"), 
 		      &alarm_defaults [ALARM_DISPLAY], ALARM_DISPLAY, 1, 
 		      FALSE, prop_changed);
@@ -896,7 +900,7 @@ create_alarm_page (void)
 static void
 prop_store_alarm_default_values (CalendarAlarm* alarm)
 {
-	ee_store_alarm (alarm, alarm->type);
+	ee_store_alarm (alarm, alarm->type, FALSE);
 
 	switch (alarm->type) {
 	case ALARM_DISPLAY:
@@ -912,10 +916,10 @@ prop_store_alarm_default_values (CalendarAlarm* alarm)
 		gnome_config_push_prefix ("/calendar/alarms/def_mail_");
 		break;
 	}
-	
+
 	gnome_config_set_int ("enabled", alarm->enabled);
-	gnome_config_set_int ("count", alarm->count);
-	gnome_config_set_int ("units", alarm->units);
+	gnome_config_set_int ("count",   alarm->count);
+	gnome_config_set_int ("units",   alarm->units);
 	if (alarm->data)
 		gnome_config_set_string ("data", alarm->data);
 	
