@@ -6,9 +6,12 @@
  *          Miguel de Icaza <miguel@nuclecu.unam.mx>
  */
 
-#include <libgnome/libgnome.h>
 #include <string.h>
+
+#include <libgnome/libgnome.h>
+
 #include "timeutil.h"
+#include "main.h"
 
 #define digit_at(x,y) (x [y] - '0')
 	
@@ -309,13 +312,15 @@ time_week_begin (time_t t)
 {
 	struct tm tm;
 
-	/* FIXME: make it take week_starts_on_monday into account */
-
 	tm = *localtime (&t);
 	tm.tm_hour = 0;
 	tm.tm_min  = 0;
 	tm.tm_sec  = 0;
-	tm.tm_mday -= tm.tm_wday;
+	if (week_starts_on_monday) {
+		tm.tm_mday -= (tm.tm_wday == 0) ? 6 : (tm.tm_wday - 1);
+	} else {
+		tm.tm_mday -= tm.tm_wday;
+	}
 
 	return mktime (&tm);
 }
@@ -325,13 +330,15 @@ time_week_end (time_t t)
 {
 	struct tm tm;
 
-	/* FIXME: make it take week_starts_on_monday into account */
-
 	tm = *localtime (&t);
 	tm.tm_hour = 0;
 	tm.tm_min  = 0;
 	tm.tm_sec  = 0;
-	tm.tm_mday += 7 - tm.tm_wday;
+	if (week_starts_on_monday) {
+		tm.tm_mday += 6 - (tm.tm_wday == 0) ? 6 : (tm.tm_wday - 1);
+	} else {
+		tm.tm_mday += 6 - tm.tm_wday;
+	}
 
 	return mktime (&tm);
 }
