@@ -17,6 +17,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>
+ * (bug fixes and minor feature enhancements).
  */
 
 #include <config.h>
@@ -153,6 +156,7 @@ gnomecard_update_canvas(Card *crd)
 	else
 	  text2++;
 	gnomecard_canvas_text_item_set(canvastext, text2);
+	g_free (text);
 	
 	/* card name */
 	gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(canvastext), 
