@@ -17,6 +17,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>
+ * (bug fixes and minor feature enhancements).
  */
 
 #include <config.h>
@@ -73,7 +76,7 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	  return;             /* ignore partial applies */
 	
 	ce = (GnomeCardEditor *) gtk_object_get_user_data(GTK_OBJECT(widget));
-	crd = (Card *) ce->l->data;
+	crd = ce->card;
 	
 	MY_FREE(crd->fname.str);
 	MY_FREE(crd->name.family);
@@ -214,24 +217,12 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	else
 	  crd->key.type = KEY_X509;
 
-/*	gnomecard_update_list(crd);
-	gnomecard_scroll_list(ce->l);
-*/
 	gnomecard_sort_card_list_by_default();
 	gnomecard_rebuild_list();
 	gnomecard_update_canvas(crd);
 	gnomecard_set_changed(TRUE);
 }
 
-/*
-static void gnomecard_prop_close(GtkWidget *widget, gpointer node)
-{
-	((Card *) ((GList *) node)->data)->flag = FALSE;
-	
-	if ((GList *) node == gnomecard_curr_crd)
-	  gnomecard_set_edit_del(TRUE);
-}
-*/
 static void gnomecard_prop_close(GtkWidget *widget, gpointer data)
 {
     GnomeCardEditor *ce;
@@ -253,6 +244,8 @@ static void gnomecard_prop_close(GtkWidget *widget, gpointer data)
 
     if (l == gnomecard_curr_crd)
 	gnomecard_set_edit_del(TRUE);
+
+    g_free (ce);
 }
 
 static void gnomecard_take_from_name(GtkWidget *widget, gpointer data)
@@ -273,7 +266,7 @@ static void gnomecard_take_from_name(GtkWidget *widget, gpointer data)
 	g_free(name);
 }
 	
-extern void gnomecard_edit(GList *node)
+extern void gnomecard_edit(Card *crd)
 {
         static GnomeHelpMenuEntry help_entry = { NULL, "edit" };
 	GnomePropertyBox *box;
@@ -283,19 +276,16 @@ extern void gnomecard_edit(GList *node)
 	GtkWidget *radio1, *radio2, *button;
 	GtkObject *adj;
 	GtkWidget *nametable;
-	Card *crd;
 	time_t tmp_time;
 
 	help_entry.name = gnome_app_id;
 
 	ce = g_new0(GnomeCardEditor, 1);
-	ce->l = node;
-	crd = (Card *) node->data;
+	ce->card = crd;
 	
 	/* Set flag and disable Delete and Edit. */
 	crd->flag = TRUE;
 	gnomecard_set_edit_del(FALSE);
-	/*gnomecard_set_add(TRUE);*/
 	
 	box = GNOME_PROPERTY_BOX(gnome_property_box_new());
 	gtk_object_set_user_data(GTK_OBJECT(box), ce);
@@ -303,10 +293,6 @@ extern void gnomecard_edit(GList *node)
 			       "gnomecard");
 	gtk_signal_connect(GTK_OBJECT(box), "apply",
 			   (GtkSignalFunc)gnomecard_prop_apply, NULL);
-/*	gtk_signal_connect(GTK_OBJECT(box), "destroy",
-			   (GtkSignalFunc)gnomecard_prop_close, node);
-*/
-/* changed to use card ptr, not pointer to list entry containing card */
 	gtk_signal_connect(GTK_OBJECT(box), "destroy",
 			   (GtkSignalFunc)gnomecard_prop_close, crd);
 
@@ -629,11 +615,6 @@ extern void gnomecard_edit(GList *node)
 static void
 gnomecard_cancel(GtkWidget *widget, gpointer data)
 {
-	void *p;
-
-	if ((p = gtk_object_get_user_data(GTK_OBJECT(widget))) != NULL)
-		g_free(p);
-	
 	gtk_widget_destroy(widget);
 }
 
@@ -1049,7 +1030,7 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 extern void gnomecard_edit_card(GtkWidget *widget, gpointer data)
 {
     if (gnomecard_curr_crd)
-	gnomecard_edit(gnomecard_curr_crd);
+	gnomecard_edit ((Card *) gnomecard_curr_crd->data);
 }
 
 extern gboolean gnomecard_append_file(char *fname)
