@@ -17,6 +17,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>
+ * (bug fixes and minor feature enhancements).
  */
 
 #include <config.h>
@@ -79,6 +82,7 @@ GtkWidget *menu_edit, *menu_find, *menu_save, *menu_del;
 GList *gnomecard_crds = NULL;
 GList *gnomecard_curr_crd = NULL;
 
+gchar *arg_fname = NULL;
 gchar *gnomecard_fname = NULL;
 gchar *gnomecard_find_str = NULL;
 gboolean gnomecard_find_sens;
@@ -244,14 +248,14 @@ extern gboolean gnomecard_save(void)
 {
 	GList *l;
 	FILE *fp;
-	char *bak_fname, *bak_fname2, *cmd, *real_fname;
+	gchar *bak_fname, *bak_fname2, *cmd, *real_fname;
 	struct stat s;
 	char i;
 	
 	if (! *gnomecard_fname)
-	  real_fname = misc_tilde_expand ("~/.gnome/GnomeCard.gcrd");
+		real_fname = misc_tilde_expand ("~/.gnome/GnomeCard.gcrd");
 	else
-	  real_fname = gnomecard_fname;
+		real_fname = g_strdup (gnomecard_fname);
 	
 	bak_fname = g_malloc (strlen (real_fname) + 3);
 	
@@ -286,8 +290,7 @@ extern gboolean gnomecard_save(void)
 
 	fp = fopen (real_fname, "w");
 	if (! fp) {
-		if (! *gnomecard_fname)
-		  g_free (real_fname);
+		g_free (real_fname);
 		
 		return FALSE;
 	}
@@ -298,8 +301,7 @@ extern gboolean gnomecard_save(void)
 	
 	gnomecard_set_changed(FALSE);
 	
-	if (! *gnomecard_fname)
-	  g_free (real_fname);
+	g_free (real_fname);
 		
 	return TRUE;
 }
@@ -336,7 +338,7 @@ extern int gnomecard_destroy_cards(void)
     if (gnomecard_changed) {
 	GtkWidget *w;
 	char *msg;
-	char *real_fname;
+	const gchar *real_fname;
 	
 	if (! *gnomecard_fname)
 	  real_fname = _("The default file");
@@ -391,7 +393,7 @@ gnomecard_new_card(GtkWidget *widget, gpointer data)
 	gnomecard_add_card_to_list(crd);
 	
 	last = g_list_last(gnomecard_crds);
-	gnomecard_edit(last);
+	gnomecard_edit((Card *) last->data);
 	gnomecard_scroll_list(last);
 	gnomecard_set_changed(TRUE);
 }
@@ -836,7 +838,7 @@ void gnomecard_init(void)
 }
 
 static const struct poptOption options [] = {
-	{ "filename", 'f', POPT_ARG_STRING, &gnomecard_fname, 0, N_("default file to load"), N_("filename") },
+	{ "filename", 'f', POPT_ARG_STRING, &arg_fname, 0, N_("default file to load"), N_("filename") },
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
@@ -880,6 +882,8 @@ int main (int argc, char *argv[])
                                       "object",
 			              &ev);
 
+	gnomecard_fname = g_strdup (arg_fname ? arg_fname : "");
+
 	gnomecard_init();
 	gtk_main();
 	return 0;
