@@ -17,6 +17,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Changed in 2002 by Sebastian Rittau <srittau@jroger.in-berlin.de>
+ * (bug fixes and minor feature enhancements).
  */
 
 /* Handle list view of avialable cards */
@@ -112,7 +115,7 @@ gnomecard_list_selected(GtkCList *list, gint row, gint column,
 	    if (event->type == GDK_2BUTTON_PRESS) {
 		/* see if card if is being editted */
 		if (!((Card *) gnomecard_curr_crd->data)->flag)
-		    gnomecard_edit(tmp);
+		    gnomecard_edit((Card *) tmp->data);
 	    } else {
 		gnomecard_set_curr(tmp);
 	    }
@@ -392,6 +395,7 @@ gnomecard_add_card_to_list(Card *crd)
 	    tmp[col] = "";
 	tmp[ncols] = NULL;
 	row = gtk_clist_append(gnomecard_list, tmp);
+	g_free (tmp);
 
 	rowtxt = gnomecardCreateColValues(crd, cols);
 	for (col=0, l=rowtxt; l; l=l->next, col++)
@@ -427,9 +431,14 @@ drag_data_get (GtkWidget        *widget,
 	       guint            info,
 	       guint32          time)
 {
-	Card *card = gnomecard_curr_crd->data;
+	Card *card;
 	char *data = NULL;
-	
+
+	if (!gnomecard_curr_crd->data)
+		return;
+
+	card = gnomecard_curr_crd->data;
+
 	switch (info){
 	case TARGET_TEXT: 
 		data = card_to_string (card);
